==> resin-4.0.27-src.tar.gz: resin-4.0.27/modules/quercus/src/com/caucho/quercus/expr/ClassVirtualFieldExpr.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.quercus.expr;

import java.io.IOException;
import java.util.ArrayList;

import com.caucho.quercus.Location;
import com.caucho.quercus.env.Env;
import com.caucho.quercus.env.MethodIntern;
import com.caucho.quercus.env.NullValue;
import com.caucho.quercus.env.StringValue;
import com.caucho.quercus.env.QuercusClass;
import com.caucho.quercus.env.Value;
import com.caucho.quercus.env.Var;
import com.caucho.quercus.parser.QuercusParser;
import com.caucho.util.L10N;

/**
 * Represents a PHP static field reference.
 */
public class ClassVirtualFieldExpr extends AbstractVarExpr {
  private static final L10N L = new L10N(ClassVirtualFieldExpr.class);

  protected final StringValue _varName;

  public ClassVirtualFieldExpr(String varName)
  {
    _varName = MethodIntern.intern(varName);
  }
  
  //
  // function call creation
  //

  /**
   * Creates a function call expression
   */
  @Override
  public Expr createCall(QuercusParser parser,
                         Location location,
                         ArrayList<Expr> args)
    throws IOException
  {
    ExprFactory factory = parser.getExprFactory();
    
    Expr var = parser.createVar(_varName.toString());
    
    return factory.createClassVirtualMethodCall(location, var, args);
  }
  
  /**
   * Evaluates the expression.
   *
   * @param env the calling environment.
   *
   * @return the expression value.
   */
  @Override
  public Value eval(Env env)
  {
    Value qThis = env.getThis();
    QuercusClass qClass = qThis != null ? qThis.getQuercusClass() : null;
    
    if (qClass == null) {
      env.error(L.l("No calling class found for '{0}'", this));
      
      return NullValue.NULL;
    }
    
    return qClass.getStaticFieldValue(env, _varName);
  }
  
  /**
   * Evaluates the expression.
   *
   * @param env the calling environment.
   *
   * @return the expression value.
   */
  @Override
  public Var evalVar(Env env)
  {
    Value qThis = env.getThis();
    QuercusClass qClass = qThis != null ? qThis.getQuercusClass() : null;
    
    if (qClass == null) {
      env.error(L.l("No calling class found for '{0}'", this));
      
      return NullValue.NULL.toVar();
    }
    
    return qClass.getStaticFieldVar(env, _varName);
  }
  
  /**
   * Evaluates the expression.
   *
   * @param env the calling environment.
   *
   * @return the expression value.
   */
  @Override
  public Value evalAssignRef(Env env, Value value)
  {
    Value qThis = env.getThis();
    QuercusClass qClass = qThis != null ? qThis.getQuercusClass() : null;
    
    if (qClass == null) {
      env.error(L.l("No calling class found for '{0}'", this));
      
      return NullValue.NULL.toVar();
    }
    
    return qClass.setStaticFieldRef(env, _varName, value);
  }
  
  /**
   * Evaluates the expression.
   *
   * @param env the calling environment.
   *
   * @return the expression value.
   */
  public void evalUnset(Env env)
  {
    env.error(getLocation(),
              L.l("{0}::${1}: Cannot unset static variables.",
                      env.getCallingClass().getName(), _varName));
  }
  
  public String toString()
  {
    return "static::$" + _varName;
  }
}

==> resin-4.0.32-src.tar.gz: resin-4.0.32/modules/quercus/src/com/caucho/quercus/expr/ClassVirtualFieldExpr.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.quercus.expr;

import java.io.IOException;
import java.util.ArrayList;

import com.caucho.quercus.Location;
import com.caucho.quercus.env.Env;
import com.caucho.quercus.env.MethodIntern;
import com.caucho.quercus.env.NullValue;
import com.caucho.quercus.env.StringValue;
import com.caucho.quercus.env.QuercusClass;
import com.caucho.quercus.env.Value;
import com.caucho.quercus.env.Var;
import com.caucho.quercus.parser.QuercusParser;
import com.caucho.util.L10N;

/**
 * Represents a PHP static field reference.
 */
public class ClassVirtualFieldExpr extends AbstractVarExpr {
  private static final L10N L = new L10N(ClassVirtualFieldExpr.class);

  protected final StringValue _varName;

  public ClassVirtualFieldExpr(StringValue varName)
  {
    _varName = varName;
  }

  //
  // function call creation
  //

  /**
   * Creates a function call expression
   */
  @Override
  public Expr createCall(QuercusParser parser,
                         Location location,
                         ArrayList<Expr> args)
    throws IOException
  {
    ExprFactory factory = parser.getExprFactory();

    Expr var = parser.createVar(_varName);

    return factory.createClassVirtualMethodCall(location, var, args);
  }

  /**
   * Evaluates the expression.
   *
   * @param env the calling environment.
   *
   * @return the expression value.
   */
  @Override
  public Value eval(Env env)
  {
    Value qThis = env.getThis();
    QuercusClass qClass = qThis != null ? qThis.getQuercusClass() : null;

    if (qClass == null) {
      env.error(L.l("No calling class found for '{0}'", this));

      return NullValue.NULL;
    }

    return qClass.getStaticFieldValue(env, _varName);
  }

  /**
   * Evaluates the expression.
   *
   * @param env the calling environment.
   *
   * @return the expression value.
   */
  @Override
  public Var evalVar(Env env)
  {
    Value qThis = env.getThis();
    QuercusClass qClass = qThis != null ? qThis.getQuercusClass() : null;

    if (qClass == null) {
      env.error(L.l("No calling class found for '{0}'", this));

      return NullValue.NULL.toVar();
    }

    return qClass.getStaticFieldVar(env, _varName);
  }

  /**
   * Evaluates the expression.
   *
   * @param env the calling environment.
   *
   * @return the expression value.
   */
  @Override
  public Value evalAssignRef(Env env, Value value)
  {
    Value qThis = env.getThis();
    QuercusClass qClass = qThis != null ? qThis.getQuercusClass() : null;

    if (qClass == null) {
      env.error(L.l("No calling class found for '{0}'", this));

      return NullValue.NULL.toVar();
    }

    return qClass.setStaticFieldRef(env, _varName, value);
  }

  /**
   * Evaluates the expression.
   *
   * @param env the calling environment.
   *
   * @return the expression value.
   */
  public void evalUnset(Env env)
  {
    env.error(getLocation(),
              L.l("{0}::${1}: Cannot unset static variables.",
                      env.getCallingClass().getName(), _varName));
  }

  public String toString()
  {
    return "static::$" + _varName;
  }
}
